@@ -44,7 +44,7 @@ def get_qlbond(bond_info: FixedRateBond, setting: BondSetting,
                                 day_count, 
                                 [100.], 
                                 [bond_info.coupon/100])
-    qlbond = ql.Bond(0, ql.TARGET(), 
+    qlbond = ql.Bond(setting.start_basis, calendar, 
                     datestr_to_qldate(bond_info.issue_date), 
                     interest)
     
