@@ -132,8 +132,16 @@ class OptionType(int,Enum):
 class OptionExercise(str, Enum):
     american = "American"
     european = "European"
+    bermudan = "Bermudan"
 
+class GeneralisedBlackScholes(str, Enum):
+    black_scholes = "Black Scholes"
+    black_scholes_merton = "Black Scholes Merton"
+    generalized_black_scholes  = "Generalized Black Scholes"
+    black = "Black"
+    garmankohlagen = "Garman Kohlagen"
 
+    
 class StochasticProcess(str, Enum):
     geometric_brownian_motion = "Geometric Brownian Motion"
     black_scholes = "Black Scholes"
